api.authentication.v1.sms.sms_authenticate — Argus-Toolbelt 1.0 documentation

# Source code for api.authentication.v1.sms.sms_authenticate

    """Autogenerated API"""
    import requests
    from argus_cli.plugin import register_command

    @register_command(extending=('authentication','v1','sms','authenticate'))
    def authenticate(userName: str = None, domain: str = None, mode: str = None, passcode: str = None, cookie: str = None,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Initiate a new user session using SMS authentication (PUBLIC)
    Requires SMS authentication to be enabled on the server, and for the user.
    Use /methods to check which authentication methods are available on the server.

    This is a 2-step authentication method. The first request should have mode PASSWORD, and carry username and static password.
    The request will return a challenge, carrying a session cookie.When the SMS code is received, submit a new request with mode VERIFICATION, the username, SMS code (in the passcode) and the session cookie returned in the challenge.

        :param str userName: Username to authenticate
        :param str domain: User domain
        :param str mode: Use PASSWORD for initial request, and SMS to respond with SMS code
        :param str passcode: Password or SMS code
        :param str cookie: When responding with SMS code, set the SMS session cookie returned by challenge
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :raises NotFoundException: on 404
        :returns: {"offset": 109, "limit": 540, "responseCode": 200, "count": 297, "metaData": {"additionalProperties": {}}, "messages": [{"message": "Month scene nothing drive vote.", "messageTemplate": "Foreign project always small certain development wait.", "field": "Lead Congress charge east wide whether project.", "parameter": {}, "timestamp": 319352005}], "currentPage": 289, "size": 155}
        """
        from requests import post
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/authentication/v1/sms/authenticate".format()
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if userName:
            body.update({"userName": userName})

        if domain:
            body.update({"domain": domain})

        if mode:
            body.update({"mode": mode})

        if passcode:
            body.update({"passcode": passcode})

        if cookie:
            body.update({"cookie": cookie})

        response = post(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response